<?php
require_once plugin_dir_path(__FILE__) . 'message-sender.php';
// Create the plugin settings page
function whatsapp_messaging_settings_page() {
    add_menu_page(
        'Onyx WhatsApp Messaging Settings',
        'Onyx WhatsApp Messaging',
        'manage_options',
        'whatsapp-messaging-settings',
        'whatsapp_messaging_settings_callback'
    );
}

add_action('admin_menu', 'whatsapp_messaging_settings_page');


// Function to validate and save API credentials
function validate_and_save_api_credentials($api_id, $api_key) {
    $api_url = "https://onyxberry.com/services/wapi/api2/validate_credentials/$api_id/$api_key/print";

    $response = wp_remote_get($api_url);


    if (is_wp_error($response)) {
        update_option('whatsapp_messaging_package_status','');
        return array('success' => false, 'message' => 'Error while validating credentials.');
       
    } else {
        $body = wp_remote_retrieve_body($response);
        $response_data = json_decode($body);

                        // Save the valid API credentials to options
                        update_option('whatsapp_messaging_api_id', $api_id);
                        update_option('whatsapp_messaging_api_key', $api_key);
     

        if (isset($response_data->response) && $response_data->response == 'success') {

            update_option('whatsapp_messaging_package_status', $response_data->description->status);
            update_option('whatsapp_messaging_package_expiry', $response_data->description->package_expiry);
            update_option('whatsapp_messaging_total_allowed_msgs', $response_data->description->total_allowed_msgs);
            update_option('whatsapp_messaging_total_consumed_msgs', $response_data->description->total_consumed_msgs);

            
            return array('success' => true, 'message' => 'API credentials are valid and saved.');
        } else {
            update_option('whatsapp_messaging_package_status','');
            return array('success' => false, 'message' => 'API credentials are invalid.');
        }
    }
}



function whatsapp_messaging_settings_callback() {
    // Retrieve current settings
    $api_id = get_option('whatsapp_messaging_api_id');
    $api_key = get_option('whatsapp_messaging_api_key');
    $admin_phone = get_option('whatsapp_messaging_admin_phone');
    $enable_contact_form = get_option('whatsapp_messaging_enable_contact_form');
    $enable_woocommerce_orders = get_option('whatsapp_messaging_enable_woocommerce_orders');
    $test_recipient = get_option('whatsapp_messaging_test_recipient');
    $test_message = get_option('whatsapp_messaging_test_message');

       // Retrieve the default messages from options
       $order_message = get_option('whatsapp_messaging_order_message');
       $contact_form_message = get_option('whatsapp_messaging_contact_form_message');

       $package_status = get_option('whatsapp_messaging_package_status');
       $package_expiry = get_option('whatsapp_messaging_package_expiry');
       $total_allowed_msgs = get_option('whatsapp_messaging_total_allowed_msgs');
       $total_consumed_msgs = get_option('whatsapp_messaging_total_consumed_msgs');

           // Retrieve the enable/disable options for each event
    $enable_user_registration = get_option('whatsapp_messaging_enable_user_registration');
    $enable_user_login = get_option('whatsapp_messaging_enable_user_login');
    $enable_comment_submission = get_option('whatsapp_messaging_enable_comment_submission');
    $enable_post_publish = get_option('whatsapp_messaging_enable_post_publish');
    $enable_post_update = get_option('whatsapp_messaging_enable_post_update');
    $enable_password_reset = get_option('whatsapp_messaging_enable_password_reset');

    // Retrieve the custom messages for each event
    $user_registration_message = get_option('whatsapp_messaging_user_registration_message');
    $user_login_message = get_option('whatsapp_messaging_user_login_message');
    $comment_submission_message = get_option('whatsapp_messaging_comment_submission_message');
    $post_publish_message = get_option('whatsapp_messaging_post_publish_message');
    $post_update_message = get_option('whatsapp_messaging_post_update_message');
    $password_reset_message = get_option('whatsapp_messaging_password_reset_message');

  
    ?>
    <div class="wrap">
        <h2>WhatsApp Messaging Settings</h2>
        <style>

        tr>td>input[type=checkbox]{
            position: relative;
            bottom: 40px;
        }
        </style>
        <form method="post" action="">
            <?php //settings_fields('whatsapp-messaging-settings-group'); ?>
            <?php //do_settings_sections('whatsapp-messaging-settings'); ?>
            <table class="form-table">
                <?php
                if($package_status){
                    ?>
                    
                <tr>
                    <td colspan='2' scope="row" style="background: #4be4ca;">
                        <strong>Package Expiry:</strong> <?php echo $package_expiry; ?>
                        <strong>Total Messages:</strong> <?php echo $total_allowed_msgs; ?>
                        <strong>Total Remaining Messages:</strong> <?php echo $total_allowed_msgs - $total_consumed_msgs; ?>
                    </td>
                </tr>
                    
                    <?php
                }
                ?>
                <tr>
                    <th scope="row">API ID*:</th>
                    <td><input type="text" name="whatsapp_messaging_api_id" value="<?php echo esc_attr($api_id); ?>" /> <a href='https://onyxberry.com/services/wapi/' target='_blank'>Get New API Key Information.</a></td>
                 
                </tr>
                <tr>
                    <th scope="row">API Key*:</th>
                    <td><input type="text" name="whatsapp_messaging_api_key" value="<?php echo esc_attr($api_key); ?>" /></td>
                </tr>
                <tr>
                    <th scope="row">Admin WhatsApp Number For Notifications:</th>
                    <td><input type="text" name="whatsapp_messaging_admin_phone" value="<?php echo esc_attr($admin_phone); ?>" /></td>
                </tr>
              
                <tr>
                <td> <hr></td>
                <td> <h3>Customer's Notifications</h3></td>
               
                </tr>

                <tr>
                <th scope="row">Woocommerce Orders:</th>
                <td>
                <input type="checkbox" name="whatsapp_messaging_enable_contact_form" value="1" <?php checked(1, $enable_contact_form); ?> />
         
                    <textarea name="whatsapp_messaging_order_message" rows="4" cols="50"><?php echo esc_textarea($order_message); ?></textarea>
                    <small>Short Codes: {{order_id}}, {{full_name}}, {{order_total}}</small>
                
                    
                </td>
            </tr>
            <tr>
                <th scope="row">Contact Form 7:</th>
                <td>
                <input type="checkbox" name="whatsapp_messaging_enable_woocommerce_orders" value="1" <?php checked(1, $enable_woocommerce_orders); ?> />
           
                <textarea name="whatsapp_messaging_contact_form_message" rows="4" cols="50"><?php echo esc_textarea($contact_form_message); ?></textarea></td>
            </tr>
            <tr>
                <th scope="row">User Registration:</th>
                <td>
                    <input type="checkbox" name="whatsapp_messaging_enable_user_registration" <?php checked($enable_user_registration, 1); ?> />
               
                    <!-- <label for="whatsapp_messaging_user_registration_message">Custom Message:</label> -->
                    <textarea name="whatsapp_messaging_user_registration_message" rows="4" cols="50"><?php echo esc_textarea($user_registration_message); ?></textarea>
                    <small>Short Codes: {{user_name}}, {{user_email}}</small>
                </td>
            </tr>
            <tr>
                <td> <hr></td>
                <td> <h3>Admin's Notifications</h3></td>
               
                </tr>
            <tr>
                <th scope="row">User Login:</th>
                <td>
                    <input type="checkbox" name="whatsapp_messaging_enable_user_login" <?php checked($enable_user_login, 1); ?> />
             
                    <!-- <label for="whatsapp_messaging_user_login_message">Custom Message:</label> -->
                    <textarea name="whatsapp_messaging_user_login_message" rows="4" cols="50"><?php echo esc_textarea($user_login_message); ?></textarea>
                    <small>Short Codes: {{user_name}}, {{user_email}}</small>
                </td>
            </tr>
            <tr>
                <th scope="row">Comment Submission:</th>
                <td>
                    <input type="checkbox" name="whatsapp_messaging_enable_comment_submission" <?php checked($enable_comment_submission, 1); ?> />
                
                    <!-- <label for="whatsapp_messaging_comment_submission_message">Custom Message:</label> -->
                    <textarea name="whatsapp_messaging_comment_submission_message" rows="4" cols="50"><?php echo esc_textarea($comment_submission_message); ?></textarea>
                    <small>Short Codes: {{user_name}}, {{user_email}}, {{comment_author}}, {{comment_content}}</small>
                </td>
            </tr>
            <tr>
                <th scope="row">Post/Publish Updates:</th>
                <td>
                    <input type="checkbox" name="whatsapp_messaging_enable_post_publish" <?php checked($enable_post_publish, 1); ?> />
            
                    <!-- <label for="whatsapp_messaging_post_publish_message">Custom Message:</label> -->
                    <textarea name="whatsapp_messaging_post_publish_message" rows="4" cols="50"><?php echo esc_textarea($post_publish_message); ?></textarea>
                    <small>Short Codes: {{user_name}}, {{user_email}}, {{post_title}}, {{post_content}}</small>
                </td>
            </tr>
            <tr>
                <th scope="row">Post Updates:</th>
                <td>
                    <input type="checkbox" name="whatsapp_messaging_enable_post_update" <?php checked($enable_post_update, 1); ?> />
             
                    <!-- <label for="whatsapp_messaging_post_update_message">Custom Message:</label> -->
                    <textarea name="whatsapp_messaging_post_update_message" rows="4" cols="50"><?php echo esc_textarea($post_update_message); ?></textarea>
                    <small>Short Codes: {{user_name}}, {{user_email}}, {{post_title}}, {{post_content}}</small>
                </td>
            </tr>
            <!-- <tr>
                <th scope="row">Password Reset:</th>
                <td>
                    <input type="checkbox" name="whatsapp_messaging_enable_password_reset" <?php // checked($enable_password_reset, 1); ?> />
             
                 <label for="whatsapp_messaging_password_reset_message">Custom Message:</label> 
                    <textarea name="whatsapp_messaging_password_reset_message" rows="4" cols="50"><?php // echo esc_textarea($password_reset_message); ?></textarea>
                </td>
            </tr> -->
             
            </table>
            <!-- <input type="submit" class="button-primary" value="Save Settings"> -->
            <input type="submit" name="validate_and_save_api_credentials" class="button-primary" value="Save & Validate API Credentials" />
        </form>
        <h2>Test WhatsApp Messaging</h2>
        <form method="post" action="">
            <table class="form-table">
                <tr>
                    <th scope="row">Test Recipient:</th>
                    <td><input type="text" name="whatsapp_messaging_test_recipient" value="<?php echo esc_attr($test_recipient); ?>" /></td>
                </tr>
                <tr>
                    <th scope="row">Test Message:</th>
                    <td><input type="text" name="whatsapp_messaging_test_message" value="<?php echo esc_attr($test_message); ?>" /></td>
                </tr>
            </table>
            <input type="submit" name="whatsapp_messaging_test_button" class="button-primary" value="Send Test Message" />
        </form>
    </div>
    <?php
}

// Handle form submission for API credentials validation and saving
if (isset($_POST['validate_and_save_api_credentials'])) {
    $api_id = sanitize_text_field($_POST['whatsapp_messaging_api_id']);
    $api_key = sanitize_text_field($_POST['whatsapp_messaging_api_key']);

    // Save the default messages for orders and contact form responses
    update_option('whatsapp_messaging_admin_phone', sanitize_text_field($_POST['whatsapp_messaging_admin_phone']));
    update_option('whatsapp_messaging_order_message', sanitize_text_field($_POST['whatsapp_messaging_order_message']));
    update_option('whatsapp_messaging_contact_form_message', sanitize_text_field($_POST['whatsapp_messaging_contact_form_message']));

    update_option('whatsapp_messaging_user_registration_message', sanitize_text_field($_POST['whatsapp_messaging_user_registration_message']));
    update_option('whatsapp_messaging_user_login_message', sanitize_text_field($_POST['whatsapp_messaging_user_login_message']));
    update_option('whatsapp_messaging_comment_submission_message', sanitize_text_field($_POST['whatsapp_messaging_comment_submission_message']));
    update_option('whatsapp_messaging_post_publish_message', sanitize_text_field($_POST['whatsapp_messaging_post_publish_message']));
    update_option('whatsapp_messaging_post_update_message', sanitize_text_field($_POST['whatsapp_messaging_post_update_message']));
    update_option('whatsapp_messaging_password_reset_message', sanitize_text_field($_POST['whatsapp_messaging_password_reset_message']));

            // Save the enable/disable options for each event
            update_option('whatsapp_messaging_enable_user_registration', isset($_POST['whatsapp_messaging_enable_user_registration']) ? 1 : 0);
            update_option('whatsapp_messaging_enable_user_login', isset($_POST['whatsapp_messaging_enable_user_login']) ? 1 : 0);
            update_option('whatsapp_messaging_enable_comment_submission', isset($_POST['whatsapp_messaging_enable_comment_submission']) ? 1 : 0);
            update_option('whatsapp_messaging_enable_post_publish', isset($_POST['whatsapp_messaging_enable_post_publish']) ? 1 : 0);
            update_option('whatsapp_messaging_enable_post_update', isset($_POST['whatsapp_messaging_enable_post_update']) ? 1 : 0);
            update_option('whatsapp_messaging_enable_password_reset', isset($_POST['whatsapp_messaging_enable_password_reset']) ? 1 : 0);

    $validation_result = validate_and_save_api_credentials($api_id, $api_key);

    if ($validation_result['success']) {
        echo '<div class="notice notice-success"><p>Success: ' . esc_html($validation_result['message']) . '</p></div>';
    } else {
        echo '<div class="notice notice-error"><p>Error: ' . esc_html($validation_result['message']) . '</p></div>';
    }
}


// Handle test message button click
if (isset($_POST['whatsapp_messaging_test_button'])) {
    $test_recipient = sanitize_text_field($_POST['whatsapp_messaging_test_recipient']);
    $test_message = sanitize_text_field($_POST['whatsapp_messaging_test_message']);
    
    // Call a function to send the test message
    $test_result = send_whatsapp_message($test_recipient, $test_message);
    // print_r($test_result);

    if ($test_result['success']) {
        echo '<div class="notice notice-success"><p>Success: ' . esc_html($test_result['message']) . '</p></div>';
    } else {
        echo '<div class="notice notice-error"><p>Error: ' . esc_html($test_result['message']) . '</p></div>';
    }
}

// Register plugin settings and fields
function whatsapp_messaging_register_settings() {
    register_setting('whatsapp-messaging-settings-group', 'whatsapp_messaging_api_id');
    register_setting('whatsapp-messaging-settings-group', 'whatsapp_messaging_api_key');
    register_setting('whatsapp-messaging-settings-group', 'whatsapp_messaging_enable_contact_form');
    register_setting('whatsapp-messaging-settings-group', 'whatsapp_messaging_enable_woocommerce_orders');
    // Add more settings as needed
}


add_action('admin_init', 'whatsapp_messaging_register_settings');

// Shortcode to display OTP verification field on registration form
function display_otp_verification_field() {
    $output = '';

    // Check if the user is logged in, if so, they don't need OTP verification
    if (is_user_logged_in()) {
        $output .= 'You are already registered and logged in.';
        return $output;
    }

    if (isset($_POST['register'])) {
        $username = sanitize_user($_POST['user_login']);
        $otp = intval($_POST['otp']);

        // Verify the OTP
        $user = get_user_by('login', $username);
        if ($user) {
            $stored_otp = get_user_meta($user->ID, 'otp', true);
            $stored_timestamp = get_user_meta($user_id, 'otp_timestamp', true);
            if ($otp == $stored_otp) {
                $current_time = time();
                $time_difference = $current_time - $stored_timestamp;
        
                if ($time_difference <= 900) { // 900 seconds (15 minutes)
                    return true; // OTP is valid
                }
            }
        
            return false; // OTP is invalid or expired
        } else {
            $output .= 'User not found.';
        }
    }

    // OTP verification form
    $output .= '<form method="post">';
    $output .= '<label for="otp">Enter OTP:</label>';
    $output .= '<input type="number" id="otp" name="otp">';
    $output .= '<input type="submit" name="register" value="Verify OTP">';
    $output .= '</form>';

    return $output;

}

add_shortcode('otp_verification', 'display_otp_verification_field');