<?php
// Include any necessary functions or classes for sending WhatsApp messages using the API



// Example function to send a WhatsApp message
function send_whatsapp_message($number, $message) {
    $api_id = get_option('whatsapp_messaging_api_id');
    $api_key = get_option('whatsapp_messaging_api_key');

    $api_url = "https://onyxberry.com/services/wapi/api2/sendtext/$api_id/$api_key";

    $response = wp_remote_post($api_url, array(
        'body' => array(
            'number' => $number,
            'message' => $message,
        ),
    ));


    if (is_wp_error($response)) {
        // Handle the error.
        return array('success' => true, 'message' => 'Message sent successfully.');
    } else {
        // Process the response (Success/Error).
        return array('success' => true, 'message' => 'Message sent successfully.');
    }
}

// Function to generate and store OTP for a user
function generate_and_store_otp($user_id) {
    $otp = mt_rand(1000, 9999); // Generate a 4-digit OTP (you can customize this length)
    $timestamp = time(); // Get the current Unix timestamp

    // Store OTP and timestamp in user meta data
    update_user_meta($user_id, 'otp', $otp);
    update_user_meta($user_id, 'otp_timestamp', $timestamp);
    update_user_meta($user_id, 'whatsapp_number', $whatsapp_number);

    return $otp;
}

// Hook into user registration to generate and store OTP
// function generate_and_store_otp_on_registration($user_id) {
//     generate_and_store_otp($user_id);
// }

// add_action('user_register', 'generate_and_store_otp_on_registration');

// Function to replace shortcode placeholders with user data
function replace_user_placeholders($message, $user) {
    $user_name = $user->display_name;
    $user_email = $user->user_email;

    $message = str_replace('{{user_name}}', $user_name, $message);
    $message = str_replace('{{user_email}}', $user_email, $message);

    return $message;
}

// Function to replace shortcode placeholders with user data
function replace_user_placeholders_for_comments($message, $user, $comment) {
    $user_name = $user->display_name;
    $user_email = $user->user_email;
    $comment_author = $comment->comment_author;
    $comment_content = $comment->comment_content;

    $message = str_replace('{{user_name}}', $user_name, $message);
    $message = str_replace('{{user_email}}', $user_email, $message);
    $message = str_replace('{{comment_author}}', $comment_author, $message);
    $message = str_replace('{{comment_content}}', $comment_content, $message);

    return $message;
}
// Function to replace shortcode placeholders with user and post data
function replace_user_and_post_placeholders($message, $user, $post) {
    $user_name = $user->display_name;
    $user_email = $user->user_email;
    $post_title = $post->post_title;
    $post_content = $post->post_content;

    $message = str_replace('{{user_name}}', $user_name, $message);
    $message = str_replace('{{user_email}}', $user_email, $message);
    $message = str_replace('{{post_title}}', $post_title, $message);
    $message = str_replace('{{post_content}}', $post_content, $message);

    return $message;
}

// Function to replace shortcode placeholders for woocommerce order
function replace_woocommerce_order_placeholders($message, $order, $order_id) {
    $full_name = $order->get_billing_first_name() . ' ' . $order->get_billing_last_name();
    $order_total = $order->get_total();

    $message = str_replace('{{full_name}}', $full_name, $message);
    $message = str_replace('{{order_total}}', $order_total, $message);
    $message = str_replace('{{order_id}}', $order_id, $message);

    return $message;
}

// Hook into WooCommerce new order event
function send_whatsapp_on_woocommerce_order($order_id) {
    $enable_woocommerce_orders = get_option('whatsapp_messaging_enable_woocommerce_orders');

    if ($enable_woocommerce_orders) {
        // Get the order details and recipient's phone number.
        $order = wc_get_order($order_id);
        // echo "<pre>";
        // print_r($order);
        // echo "</pre>";
        // exit();

        // Get customer phone number from the order (if available)
        $customer_phone = '';
        if ($order) {
            $billing_phone = $order->get_billing_phone();
            $shipping_phone = $order->get_shipping_phone();
            $customer_phone = !empty($billing_phone) ? $billing_phone : $shipping_phone;
        }

        // Get the previously saved default message for orders
        $message = get_option('whatsapp_messaging_order_message', 'Your new order has been placed.');
        $message = replace_woocommerce_order_placeholders($message, $order, $order_id);

        if (!empty($customer_phone)) {

            send_whatsapp_message($customer_phone, $message);
        }

                // Send an admin notification
        $admin_phone = get_option('whatsapp_messaging_admin_phone');
        if (!empty($admin_phone)) {
            // Customize the message to include order details
            $admin_message = 
            '*New order received:*
            Order ID: ' . $order_id. '
            Customer: ' . $order->get_billing_first_name() . ' ' . $order->get_billing_last_name();
           $admin_message .= '
           Total Amount: ' . $order->get_total() . ''; //$order->get_formatted_order_total()

            send_whatsapp_message($admin_phone, $admin_message);
        }
    }
}

add_action('woocommerce_new_order', 'send_whatsapp_on_woocommerce_order');

// Hook into Contact Form 7 mail sent event (modify to suit your specific contact form plugin)
function send_whatsapp_on_contact_form_submission($contact_form) {
    $enable_contact_form = get_option('whatsapp_messaging_enable_contact_form');

    if ($enable_contact_form) {
        // Get the submitted data and recipient's phone number.
        $submission = WPCF7_Submission::get_instance();

        if ($submission) {
            $posted_data = $submission->get_posted_data();

            // Replace 'phone_number_field' with the actual field name for the user's phone number in your contact form.
            $user_phone_number = !empty($posted_data['number-768']) ? $posted_data['phone_number_field'] : '';

            // Get the previously saved custom message for contact form submissions
            $message = get_option('whatsapp_messaging_contact_form_message', 'You have received a contact form submission.');

            if (!empty($user_phone_number)) {
                send_whatsapp_message($user_phone_number, $message);
            }
            $admin_phone_number = get_option('whatsapp_messaging_admin_phone');

            if (!empty($admin_phone_number)) {
                // Customize the message for admin notification, including the form submission data.
                $admin_message = 'New contact form submission:
                    ';
                foreach ($posted_data as $field_name => $field_value) {
                    $admin_message .= $field_name . ': ' . $field_value . '
                    ';
                }

                send_whatsapp_message($admin_phone_number, $admin_message);
            }
        }
    }
}

add_action('wpcf7_mail_sent', 'send_whatsapp_on_contact_form_submission');

// Handle user registration event
function send_whatsapp_on_user_registration($user_id, $user_phone_number) {
    $enable_user_registration = get_option('whatsapp_messaging_enable_user_registration');

    if ($enable_user_registration) {
        // Get user details and recipient's phone numbers.
        $user = get_userdata($user_id);
        $admin_phone_number = get_option('whatsapp_messaging_admin_phone');

        // Get the previously saved custom message for user registration.
        $user_message = get_option('whatsapp_messaging_user_registration_message', 'Welcome to our website.');
        $user_message = replace_user_placeholders($user_message, $user);

        if (!empty($user_phone_number)) {
            send_whatsapp_message($user_phone_number, $user_message);
            $otp = generate_and_store_otp($user_id);
            send_whatsapp_message($admin_phone_number, 'Your OTP is: '. $otp);
        }

        if (!empty($admin_phone_number)) {
            // Customize the message for admin notification, including user registration details.
            $admin_message = 'New user registered:
            ';
            $admin_message .= 'Username: ' . $user->user_login . '
            ';
            $admin_message .= 'Email: ' . $user->user_email . '
            ';
            
            send_whatsapp_message($admin_phone_number, $admin_message);
        }
    }

}

add_action('user_register', 'send_whatsapp_on_user_registration');

// Handle user login event
function send_whatsapp_on_user_login($user_login, $user) {
    $enable_user_login = get_option('whatsapp_messaging_enable_user_login');

    if ($enable_user_login) {
        // Get the recipient's phone number.
        $recipient_phone_number = get_option('whatsapp_messaging_admin_phone');

        // Get the previously saved custom message for user login
        $message = get_option('whatsapp_messaging_user_login_message', 'Welcome back, {{user_name}}.');
        $message = replace_user_placeholders($message, $user);

        send_whatsapp_message($recipient_phone_number, $message);
    }

}

add_action('wp_login', 'send_whatsapp_on_user_login', 10, 2);

// Handle comment submission event
function send_whatsapp_on_comment_submission($comment_ID, $comment) {

    $enable_comment_notifications = get_option('whatsapp_messaging_enable_comment_submission');
    $comment_message_template = get_option('whatsapp_messaging_comment_submission_message', 'New comment by {{comment_author}}: {{comment_content}}');

    if ($enable_comment_notifications) {
        $comment = get_comment($comment_ID);
 
        $user = get_userdata($comment->user_id);
        $comment_message = replace_user_placeholders_for_comments($comment_message_template, $user, $comment);

        // Send the WhatsApp message with the replaced message
        send_whatsapp_message(get_option('whatsapp_messaging_admin_phone'), $comment_message);
    }
}

add_action('comment_post', 'send_whatsapp_on_comment_submission', 10, 2);

// Handle post publish event
function send_whatsapp_on_post_publish($post_id, $post) {
    $enable_post_publish = get_option('whatsapp_messaging_enable_post_publish');

    if ($enable_post_publish) {
        // Get the recipient's phone number.
        $recipient_phone_number = get_option('whatsapp_messaging_admin_phone');

        // Get the previously saved custom message for post publish
        $message = get_option('whatsapp_messaging_post_publish_message', 'New post published: {{post_title}}');

        $post = get_post($post_id);
        $user = get_userdata($post->post_author);
        $message = replace_user_and_post_placeholders($message, $user, $post);


        send_whatsapp_message($recipient_phone_number, $message);
    }
}

add_action('publish_post', 'send_whatsapp_on_post_publish');

// Handle post update event
function send_whatsapp_on_post_update($post_id, $post_after, $post_before) {
    $enable_post_update = get_option('whatsapp_messaging_enable_post_update');

    if ($enable_post_update) {
        // Get the recipient's phone number.
        $recipient_phone_number = get_option('whatsapp_messaging_admin_phone');

        // Get the previously saved custom message for post updates
        $message = get_option('whatsapp_messaging_post_update_message', 'A post has been updated: {{post_title}}');

        $post = get_post($post_id);
        $user = get_userdata($post->post_author);
        $message = replace_user_and_post_placeholders($message, $user, $post);


        send_whatsapp_message($recipient_phone_number, $message);
    }
}

add_action('save_post', 'send_whatsapp_on_post_update', 10, 3);
